@@ -18,7 +18,7 @@ def setup_services(services: List[str], skip_existing: bool) -> None:
     if not "git_url" in CONFIG:
         raise typer.BadParameter("You must set the git_url in the config file before you can use this command")
     if not PYENV_INSTALLED:
-        typer.echo("Failed to locate pyenv. Will use the system python version(s) instead")
+        typer.echo("Failed to locate pyenv. Will use the system python version(s) instead", err=True)
     installable_pyenv_versions = [
         clean_python_version(" \t~^*") for v in sh("pyenv install --list", capture=True).stdout.split("\n") if v.strip()
     ]
@@ -30,7 +30,7 @@ def setup_services(services: List[str], skip_existing: bool) -> None:
 
 
 def setup_service(repo_name: str, git_link: str, installable_pyenv_versions: List[str]):
-    typer.echo(f"Setting up {repo_name}")
+    typer.echo(f"Setting up {repo_name}", err=True)
     success = clone_repo(git_link)
 
     if success:
@@ -60,7 +60,9 @@ def get_python_version(pyproject_path: Path) -> Optional[str]:
     if version_info:
         return f"{version_info[0]}.{version_info[1]}"
     else:
-        typer.echo("Failed to read python version from pyproject.toml. It's either invalid or too complex for me.")
+        typer.echo(
+            "Failed to read python version from pyproject.toml. It's either invalid or too complex for me.", err=True
+        )
 
 
 def setup_pyenv_locally(python_version: str, installable_pyenv_versions: List[str]):
@@ -102,7 +104,7 @@ def get_repositories_to_clone(repo_names: List[str], skip_existing: bool) -> Lis
             expanded_repo_names.append((name.split("/")[-1], f'{CONFIG["git_url"]}:{name}.git'))
         else:
             with requests.Session() as session:
-                session.headers = {"PRIVATE-TOKEN": CONFIG["gitlab_api_token"]}
+                session.headers = {"PRIVATE-TOKEN": CONFIG.get_api_token()}
                 project_jsons = _paginated_get(f"{get_gitlab_api_url()}/projects", session)
 
                 projects = [
